@@ -3,7 +3,7 @@ from typing import Optional
 
 
 class AppliedCoupon(BaseModel):
-    customer_id: str
+    external_customer_id: str
     coupon_code: str
     amount_cents: Optional[int]
     amount_currency: Optional[str]
@@ -13,7 +13,7 @@ class AppliedCouponResponse(BaseModel):
     lago_id: str
     lago_coupon_id: str
     coupon_code: str
-    customer_id: str
+    external_customer_id: str
     lago_customer_id: str
     amount_cents: int
     amount_currency: str
